@@ -1,8 +1,7 @@
 package rules
 
 import (
-	"regexp"
-
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
 
@@ -11,13 +10,13 @@ func Databricks() *config.Rule {
 	r := config.Rule{
 		Description: "Databricks API token",
 		RuleID:      "databricks-api-token",
-		Regex:       regexp.MustCompile(`dapi[a-h0-9]{32}`),
+		Regex:       generateUniqueTokenRegex(`dapi[a-h0-9]{32}`),
 		Keywords:    []string{"dapi"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("databricks", "dapi"+sampleHex32Token),
+		generateSampleSecret("databricks", "dapi"+secrets.NewSecret(hex("32"))),
 	}
-	return validate(r, tps)
+	return validate(r, tps, nil)
 }
